==> haskell-prettyprinter-interp-0.2.0.0-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-interp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-interp
version:              0.2.0.0
visibility:           public
id:                   prettyprinter-interp-0.2.0.0-EQre3HoJ0lGCxDlU7u2tLG
key:                  prettyprinter-interp-0.2.0.0-EQre3HoJ0lGCxDlU7u2tLG
license:              BSD-2-Clause
copyright:            (C) 2022-2023, Peter Lebbing
maintainer:           peter@digitalbrains.com
author:               Peter Lebbing
homepage:             https://github.com/DigitalBrains1/prettyprinter-interp
synopsis:             Efficient interpolation for Prettyprinter
description:
    This package provides efficient interpolation
    of @[string-interpolate](https://hackage.haskell.org/package/string-interpolate)@
    quasi quoters when used
    with @[prettyprinter](https://hackage.haskell.org/package/prettyprinter)@.

category:             Data, Text
abi:                  6c3deab568cdaaeb0d33f8ba51e316bf
exposed:              True
exposed-modules:      Prettyprinter.Interpolate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-interp
hs-libraries:         HSprettyprinter-interp-0.2.0.0-EQre3HoJ0lGCxDlU7u2tLG
depends:
    base-4.17.2.1 prettyprinter-1.7.1-1kfTx5RMvNJHRpCjVrY3F5
    string-interpolate-0.3.4.0-8kUcREpxnR189th5H0d4Al
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-interp/html/prettyprinter-interp.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-interp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-interp-0.2.0.0-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-interp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-interp
version:              0.2.0.0
visibility:           public
id:                   prettyprinter-interp-0.2.0.0-7ay0trgjWd428wSlF2lRtz
key:                  prettyprinter-interp-0.2.0.0-7ay0trgjWd428wSlF2lRtz
license:              BSD-2-Clause
copyright:            (C) 2022-2023, Peter Lebbing
maintainer:           peter@digitalbrains.com
author:               Peter Lebbing
homepage:             https://github.com/DigitalBrains1/prettyprinter-interp
synopsis:             Efficient interpolation for Prettyprinter
description:
    This package provides efficient interpolation
    of @[string-interpolate](https://hackage.haskell.org/package/string-interpolate)@
    quasi quoters when used
    with @[prettyprinter](https://hackage.haskell.org/package/prettyprinter)@.

category:             Data, Text
abi:                  88367265a5f6f1f1592a47eea1d98a43
exposed:              True
exposed-modules:      Prettyprinter.Interpolate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-interp
hs-libraries:         HSprettyprinter-interp-0.2.0.0-7ay0trgjWd428wSlF2lRtz
depends:
    base-4.17.2.1 prettyprinter-1.7.1-GISel4GwMefHj3FidpnW09
    string-interpolate-0.3.4.0-1DsCVE72Oao1TUek5cGW4B
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-interp/html/prettyprinter-interp.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-interp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
